/*
 *	project:	bmp2pdb (version 2)
 *	file:		bmp2pdb_2.h
 *	copy:		Collin R. Mulliner <palm@mulliner.org>
 *	www:		http://www.mulliner.org/palm/
 *	date:		Feb. 20. 2000
 *
 *	! this belongs to the MyPhone package !
 */

#include <stdio.h>
#include <ctype.h>

// for image validation
#define MAX_IMAGE_WIDTH 200
#define MAX_IMAGE_HEIGHT 200
#define DPI_RANGE_MIN 2800
#define DPI_RANGE_MAX 2900
// 72 pixels per inch

// error codes
#define IMAGE_FILE_ERROR 1
#define IMAGE_SIZE_ERROR 2
#define IMAGE_COMPRESS_ERROR 3
#define IMAGE_DPI_ERROR 4
#define IMAGE_COLOR_ERROR 5


#define BMP_HELP	"\nbmp2pdb v2 (c) by Collin R. Mulliner <palm@mulliner.org>\n\n"\
			"This program is part of the MyPhone package.\n"\
			"http://www.mulliner.org/palm/myphone/\n\n"\
			"syntax: bmp2pdb <bmp file> <pdb file> <description text>\n\n"\
			"example: 1) bmp2pdb homer.bmp homer.pdb \"Homer Simpson\"\n"\
			"         2) bmp2pdb bart.bmp bart.pdb Bart\n\n"\
			"run \"bmp2pdb\" as \"bmp2pdb_silent\" for no output\n\n"
			
#define MIDI_HELP	"\nmidi2pdb v2 (c) by Collin R. Mulliner <palm@mulliner.org>\n\n"\
			"This program is part of the MyPhone package.\n"\
			"http://www.mulliner.org/palm/myphone/\n\n"\
			"syntax: midi2pdb <midi file> <pdb file> <description text>\n\n"\
			"example: 1) midi2pdb rock.mid rock.pdb \"Rock Song\"\n"\
			"         2) midi2pdb dingdong.mid dingdong.pdb DingDong\n\n"\
			"run \"midi2pdb\" as \"midi2pdb_silent\" for no output\n\n"			
			

#define FILE_ERR_TXT		"Err: can't open BMP or PDB file\n"
#define SIZE_ERR_TXT		"Err: BMP file too big - you won't see the whole image anyway\n"
#define COMPRESS_ERR_TXT	"Err: only uncompresses images are allowed\n"
#define DPI_ERR_TXT		"Err: 72 DPI images only\n"
#define COLOR_ERR_TXT		"Err: only images with a color depth of 1, 4 or 8 bits per pixel are allowed\n"
		
// change the byte order
#define SWAP4(x) x = ((x >> 24) | ((x & 0x00ff0000) >> 8) | ((x & 0x0000ff00) << 8) | (x << 24));
#define SWAP2(x) x = ((x >> 8) | (x << 8));

#pragma pack(2)
// BMP file header
typedef struct {
	unsigned short bfType;
	unsigned int bfSize;
	unsigned short bfReserved1;
	unsigned short bfReserved2;
	unsigned int bfOffBits;
} bmfh_type;
#pragma

#pragma pack(2)
// BMP image header
typedef struct {
	unsigned int biSize;
	int biWidth;			// image width
	int biHeight;			// image height
	unsigned short biPlanes;	// must be 1
	unsigned short biBitCount;	// 1, 4, 8, 24
	unsigned int biCompression;	// 0 for no compression
	unsigned int biSizeImage;	// height * (width / (8 / biBitCount)) (pad to a 32 bit boundary)
	int biXPelsPerMeter;
	int biYPelsPerMeter;
	unsigned int biClrUsed;
	unsigned int biClrImportant;
} bmih_type;
#pragma

#pragma pack(2)
typedef struct {
	char db_name[32];
	unsigned short flags;
	unsigned short version;
	unsigned int creationTime;
	unsigned int modificationTime;
	unsigned int backupTime;
	unsigned int modificationNumber;
	unsigned int appInfoOffset;
	unsigned int sortInfoOffset;
	unsigned int typeID;
	unsigned int creatorID;
	unsigned int uniqueIDSeed;
	unsigned int nextRecordListPtr;
	unsigned short numRecords;
} pdb_db_header_type;
#pragma

#pragma pack(2)
typedef struct {
	unsigned int offset;
	unsigned char flags;
	unsigned char uniqueID[3];
} rec_header_type;
#pragma
